import React, { useEffect } from 'react';
import { BrowserRouter, Routes, Route, Navigate } from 'react-router-dom';
import { initializeProfanityFilter } from './lib/utils/profanityFilter';
import Login from './routes/auth/Login';
import Signup from './routes/auth/Signup';
import ResetPassword from './routes/auth/ResetPassword';
import Dashboard from './routes/user/Dashboard';
import Profile from './routes/user/Profile';
import Favorites from './routes/user/Favorites';
import Orders from './routes/user/Orders';
import DijiDownloads from './routes/user/DijiDownloads';
import Collections from './routes/user/Collections';
import Organizations from './routes/user/Organizations';
import CreateOrg from './routes/org/Create';
import Designs from './routes/public/Designs';
import Apparel from './routes/public/Apparel';
import Combos from './routes/public/Combos';
import HomePage from './routes/public/Home';
import { UserProvider, useUser } from './contexts/UserContext';
import { ThemeProvider } from './contexts/ThemeContext';
import Layout from './components/layout/Layout';
import { Toaster } from 'react-hot-toast';
import SitewideOverlayBanner from './components/ui/SitewideOverlayBanner';
import OrgDashboard from './routes/org/[orgSlug]/Dashboard';
import OrgProfile from './routes/org/[orgSlug]/Profile';
import OrgDesigns from './routes/org/[orgSlug]/Designs';
import OrgApparel from './routes/org/[orgSlug]/Apparel';
import OrgCombos from './routes/org/[orgSlug]/Combos';
import OrgMembers from './routes/org/[orgSlug]/Members';
import OrgSettings from './routes/org/[orgSlug]/Settings';
import OrgAddons from './routes/org/[orgSlug]/Addons';
import OrgDesignLicenses from './routes/org/[orgSlug]/DesignLicenses';
import OrgDesignLicenseAssignment from './routes/org/[orgSlug]/DesignLicenseAssignment';
import OrgAddresses from './routes/org/[orgSlug]/Addresses';
import LicenseDetails from './routes/public/LicenseDetails';
import Forgot from './routes/auth/Forgot';
import UploadDesign from './routes/org/[orgSlug]/UploadDesign';
import EditDesign from './routes/org/[orgSlug]/EditDesign';
import AdminDashboard from './routes/admin/Dashboard';
import AdminUsers from './routes/admin/Users';
import AdminUserOrders from './routes/admin/UserOrders';
import AdminOrganizations from './routes/admin/Organizations';
import AdminAddons from './routes/admin/Addons';
import AddonSettings from './routes/admin/AddonSettings';
import SystemFulfillment from './routes/admin/SystemFulfillment';
import AdminShipStation from './routes/admin/ShipStation';
import AdminOrders from './routes/admin/Orders';
import AdminOrdersV2 from './routes/admin/OrdersV2';
import DTFPrintList from './routes/admin/DTFPrintList';
import MaterialsList from './routes/admin/MaterialsList';
import SKUMapping from './routes/admin/SKUMapping';
import BulkSKUMapping from './routes/admin/BulkSKUMapping';
import AdminDesigns from './routes/admin/Designs';
import AdminDijiDownloads from './routes/admin/DijiDownloads';
import AdminApparel from './routes/admin/Apparel';
import AdminCombos from './routes/admin/Combos';
import AdminMessaging from './routes/admin/Messaging';
import AdminDesignCategories from './routes/admin/DesignCategories';
import AdminClothingCategories from './routes/admin/ClothingCategories';
import AdminClothingStyles from './routes/admin/ClothingStyles';
import AdminPageData from './routes/admin/PageData';
import ProtectedRoute from './router/ProtectedRoute';
import DesignBulkEditData from './routes/admin/DesignBulkEditData';
import DesignBulkEditDesigns from './routes/admin/DesignBulkEditDesigns';
import DesignBulkEditMockups from './routes/admin/DesignBulkEditMockups';
import DesignBulkEditCategories from './routes/admin/DesignBulkEditCategories';
import DesignBulkEditKeywords from './routes/admin/DesignBulkEditKeywords';
import DesignBulkEditThumbs from './routes/admin/DesignBulkEditThumbs';
import SiteSettings from './routes/admin/SiteSettings';
import PublicDynamicPage from './routes/public/[...page]';
import { CartProvider } from './contexts/CartContext';
import PublicOrganization from './routes/public/Organizations';
import OrgSocials from './routes/org/[orgSlug]/Socials';
import BadwordsAdmin from './routes/admin/Badwords';
import DesignDetails from './routes/public/DesignDetails';
import ApparelDetails from './routes/public/ApparelDetails';
import PublicCollections from './routes/public/Collections';
import Header from './components/layout/Header';
import ScrollToTop from './components/ui/ScrollToTop';
import ClothingStylesEdit from './routes/admin/ClothingStylesEdit';
import ClothingSizeMaps from './routes/admin/ClothingSizeMaps';
import DesignsScroller from './routes/public/DesignsScroller';
import CollectionDetails from '@/routes/user/CollectionsDetails';
import UploadDesignsBulk from './routes/org/[orgSlug]/UploadDesignsBulk';
import CreateCombo from './routes/public/CreateCombo';
import ComboDetails from './routes/public/ComboDetails';
import Cart from './routes/public/Cart';
import UserCollections from './routes/public/UserCollections';
import UserFavorites from './routes/public/UserFavorites';
import OrgCreateCombo from './routes/org/[orgSlug]/combos/create';
import EditCombo from './routes/org/[orgSlug]/combos/edit';
import UserCombos from './routes/user/Combos';
import UserAddresses from './routes/user/UserAddresses';
import DTFOrders from './routes/user/DTFOrders';
import Messages from './routes/user/Messages';
import OrgMessages from './routes/org/[orgSlug]/Messages';
import AdminMessages from './routes/admin/Messages';
import OrgDTFOrders from './routes/org/[orgSlug]/DtfOrders';
import UploadGangsheet from './routes/org/[orgSlug]/dtf/UploadGangsheet';
import DesignByNumberRedirect from './routes/org/[orgSlug]/DesignByNumberRedirect';
import ShipStationAddon from './routes/org/[orgSlug]/addons/shipstation';
import OpenAIAddon from './routes/org/[orgSlug]/addons/openai';
import { EtsyAddon } from './routes/org/[orgSlug]/addons/etsy/EtsyAddon';
import { EtsyCallback } from './routes/org/[orgSlug]/addons/etsy/EtsyCallback';
import JaneAddon from './routes/org/[orgSlug]/addons/jane';
import JaneSettings from './routes/org/[orgSlug]/addons/jane/JaneSettings';
import JaneExport from './routes/org/[orgSlug]/addons/jane/JaneExport';
import SSActivewearAddon from './routes/org/[orgSlug]/addons/ssactivewear';
import FulfillmentSettings from './routes/org/[orgSlug]/FulfillmentSettings';
import AdminAccess from './routes/admin/AdminAccess';
import OpenAIPrompts from './routes/admin/OpenAIPrompts';
import ProtectedAdminRoute from './components/admin/ProtectedAdminRoute';
import GoogleAnalytics from '@/components/analytics/GoogleAnalytics';
import HeaderCodeInsertion from '@/components/analytics/HeaderCodeInsertion';
import BulkAIData from './routes/admin/BulkAIData';
import Coupons from './routes/admin/Coupons';
import AdminEditDesign from './routes/admin/EditDesign';
import AdminBulkComplexity from './routes/admin/BulkComplexity';
import AdminOrganizationDetails from './routes/admin/OrganizationDetails';
import DuplicateDesignCleanup from './routes/admin/DuplicateDesignCleanup';
import OrgDesignBulkEditData from './routes/org/[orgSlug]/DesignBulkEditData';
import OrgDesignBulkEditDesigns from './routes/org/[orgSlug]/DesignBulkEditDesigns';
import OrgDesignBulkEditMockups from './routes/org/[orgSlug]/DesignBulkEditMockups';
import OrgDesignBulkEditCategories from './routes/org/[orgSlug]/DesignBulkEditCategories';
import OrgDesignBulkEditKeywords from './routes/org/[orgSlug]/DesignBulkEditKeywords';
import OrgDesignBulkEditThumbs from './routes/org/[orgSlug]/DesignBulkEditThumbs';
import OrgBulkAIData from './routes/org/[orgSlug]/BulkAIData';
import Featured from './routes/admin/Featured';
import ShippingPrices from './routes/admin/ShippingPrices';
import CheckoutSuccess from './routes/public/CheckoutSuccess';
import CheckoutCancel from './routes/public/CheckoutCancel';
import DataTX from './routes/admin/DataTX';
import ExclusiveLicenseAssignment from './routes/org/[orgSlug]/ExclusiveLicenseAssignment';

// A simplified layout without sidebar for specific admin pages
const NoSidebarLayout: React.FC<{ children: React.ReactNode }> = ({ children }) => {
  return (
    <div className="min-h-screen flex flex-col bg-background text-foreground dark:bg-gray-900 dark:text-white">
      <Header />
      <div className="flex flex-1 w-full">
        <main className="flex-1">{children}</main>
      </div>
      <ScrollToTop />
    </div>
  );
};

const App: React.FC = () => {
  // Initialize profanity filter cache on app startup
  useEffect(() => {
    initializeProfanityFilter().catch(console.warn);
  }, []);

  return (
    <UserProvider>
      <ThemeProvider>
        <CartProvider>
          <Toaster 
            position="top-center"
            toastOptions={{
              duration: 3000,
              style: {
                background: '#363636',
                color: '#fff',
                cursor: 'pointer',
              },
              success: {
                style: {
                  background: '#10B981',
                  cursor: 'pointer',
                },
              },
              error: {
                style: {
                  background: '#EF4444',
                  cursor: 'pointer',
                },
              },
            }}
            containerStyle={{
              cursor: 'pointer',
              top: '80px', // Push below header navigation
            }}
          />
          <BrowserRouter 
            future={{
              v7_startTransition: true,
              v7_relativeSplatPath: true
            }}
          >
            <SitewideOverlayBanner />
            <HeaderCodeInsertion />
            <GoogleAnalytics />
            <Routes>
              {/* Special routes with NoSidebarLayout */}
              <Route path="/admin/clothing-styles" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <AdminClothingStyles />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/clothing-styles/:id/edit" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <ClothingStylesEdit />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/org/:orgSlug/addons/shipstation" element={
                <NoSidebarLayout>
                  <ProtectedRoute>
                    <ShipStationAddon />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/org/:orgSlug/addons/openai" element={
                <NoSidebarLayout>
                  <ProtectedRoute>
                    <OpenAIAddon />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/org/:orgSlug/addons/etsy" element={
                <NoSidebarLayout>
                  <ProtectedRoute>
                    <EtsyAddon />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/org/:orgSlug/addons/etsy/callback" element={
                <NoSidebarLayout>
                  <ProtectedRoute>
                    <EtsyCallback />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/org/:orgSlug/addons/jane" element={
                <NoSidebarLayout>
                  <ProtectedRoute>
                    <JaneAddon />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/org/:orgSlug/addons/jane/settings" element={
                <NoSidebarLayout>
                  <ProtectedRoute>
                    <JaneSettings />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/org/:orgSlug/addons/jane/export" element={
                <NoSidebarLayout>
                  <ProtectedRoute>
                    <JaneExport />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/org/:orgSlug/addons/ssactivewear" element={
                <NoSidebarLayout>
                  <ProtectedRoute>
                    <SSActivewearAddon />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/shipstation" element={
                <NoSidebarLayout>
                  <ProtectedAdminRoute pageKey="shipstation">
                    <AdminShipStation />
                  </ProtectedAdminRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/shipstation/dtf-print-list" element={
                <NoSidebarLayout>
                  <ProtectedAdminRoute pageKey="shipstation.dtf-print-list">
                    <DTFPrintList />
                  </ProtectedAdminRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/shipstation/materials-list" element={
                <NoSidebarLayout>
                  <ProtectedAdminRoute pageKey="shipstation.materials-list">
                    <MaterialsList />
                  </ProtectedAdminRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/shipstation/sku-mapping" element={
                <NoSidebarLayout>
                  <ProtectedAdminRoute pageKey="shipstation.sku-mapping">
                    <SKUMapping />
                  </ProtectedAdminRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/shipstation/bulk-sku-mapping" element={
                <NoSidebarLayout>
                  <ProtectedAdminRoute pageKey="shipstation.bulk-sku-mapping">
                    <BulkSKUMapping />
                  </ProtectedAdminRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/admin-access" element={
                <NoSidebarLayout>
                  <ProtectedAdminRoute pageKey="admin-access" requireSuperAdmin={true}>
                    <AdminAccess />
                  </ProtectedAdminRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/organizations" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <AdminOrganizations />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/organizations/:id/details" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <AdminOrganizationDetails />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/duplicate-design-cleanup" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <DuplicateDesignCleanup />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/designs" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <AdminDesigns />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/diji-downloads" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole={['admin', 'superadmin']}>
                    <AdminDijiDownloads />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/designs/:designId/edit" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <AdminEditDesign />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/designs/bulk-data" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <DesignBulkEditData />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/designs/bulk-designs" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <DesignBulkEditDesigns />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/designs/bulk-mockups" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <DesignBulkEditMockups />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/designs/bulk-categories" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <DesignBulkEditCategories />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/designs/bulk-keywords" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <DesignBulkEditKeywords />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/designs/bulk-thumbs" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <DesignBulkEditThumbs />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/designs/bulk-ai-data" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <BulkAIData />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/designs/bulk-complexity" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <AdminBulkComplexity />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/users" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <AdminUsers />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/users/:userId/orders" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole="superadmin">
                    <AdminUserOrders />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/orders" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole={['admin', 'superadmin']}>
                    <AdminOrders />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              <Route path="/admin/orders-v2" element={
                <NoSidebarLayout>
                  <ProtectedRoute requireRole={['admin', 'superadmin']}>
                    <AdminOrdersV2 />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              
              {/* Organization Designs - Full Width Layout */}
              <Route path="/org/:orgSlug/designs" element={
                <NoSidebarLayout>
                  <ProtectedRoute>
                    <OrgDesigns />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              
              {/* Exclusive License Assignment - Full Width Layout */}
              <Route path="/org/:orgSlug/exclusive-license-assignment" element={
                <NoSidebarLayout>
                  <ProtectedRoute>
                    <ExclusiveLicenseAssignment />
                  </ProtectedRoute>
                </NoSidebarLayout>
              } />
              
              {/* Global Etsy OAuth Callback */}
              <Route path="/etsy/callback" element={
                <NoSidebarLayout>
                  <EtsyCallback />
                </NoSidebarLayout>
              } />
              
              {/* All other routes with standard Layout */}
              <Route path="/*" element={
                <Layout>
                  <Routes>
                    <Route path="/" element={<HomePage />} />
                    <Route path="/auth/login" element={<Login />} />
                    <Route path="/auth/signup" element={<Signup />} />
                    <Route path="/auth/forgot" element={<Forgot />} />
                    <Route path="/auth/reset-password" element={<ResetPassword />} />
                    <Route
                      path="/user/dashboard"
                      element={
                        <ProtectedRoute>
                          <Dashboard />
                        </ProtectedRoute>
                      }
                    />
                    <Route path="/user/profile" element={<ProtectedRoute><Profile /></ProtectedRoute>} />
                    <Route path="/user/favorites" element={<ProtectedRoute><Favorites /></ProtectedRoute>} />
                    <Route path="/user/orders" element={<ProtectedRoute><Orders /></ProtectedRoute>} />
                    <Route path="/user/diji-downloads" element={<ProtectedRoute><DijiDownloads /></ProtectedRoute>} />
                    <Route path="/user/addresses" element={<ProtectedRoute><UserAddresses /></ProtectedRoute>} />
                    <Route path="/user/dtf-orders" element={<ProtectedRoute><DTFOrders /></ProtectedRoute>} />
                    <Route path="/user/collections" element={<ProtectedRoute><Collections /></ProtectedRoute>} />
                    <Route path="/user/collections/:collectionId" element={<CollectionDetails />} />
                    <Route path="/user/combos" element={<ProtectedRoute><UserCombos /></ProtectedRoute>} />
                    <Route path="/user/messages" element={<ProtectedRoute><Messages /></ProtectedRoute>} />
                    <Route path="/user/organizations" element={<ProtectedRoute><Organizations /></ProtectedRoute>} />
                    <Route path="/org/create" element={<ProtectedRoute><CreateOrg /></ProtectedRoute>} />
                    <Route path="/designs" element={<Designs />} />
                    <Route path="/designs/scroller" element={<Layout hideHeader><DesignsScroller /></Layout>} />
                    <Route path="/apparel" element={<Apparel />} />
                    <Route path="/combos" element={<Combos />} />
                    <Route path="/combos/create" element={<CreateCombo />} />
                    <Route path="/cart" element={<Cart />} />
                    <Route path="/org/:orgSlug/dashboard" element={<ProtectedRoute><OrgDashboard /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/addons" element={<ProtectedRoute><OrgAddons /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/profile" element={<ProtectedRoute><OrgProfile /></ProtectedRoute>} />

                    <Route path="/org/:orgSlug/licenses" element={<ProtectedRoute><OrgDesignLicenses /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs-licenses" element={<ProtectedRoute><OrgDesignLicenseAssignment /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/addresses" element={<ProtectedRoute><OrgAddresses /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/apparel" element={<ProtectedRoute><OrgApparel /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/combos" element={<ProtectedRoute><OrgCombos /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/combos/create" element={<ProtectedRoute><OrgCreateCombo /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/combos/:comboId/edit" element={<ProtectedRoute><EditCombo /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/messages" element={<ProtectedRoute><OrgMessages /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/members" element={<ProtectedRoute><OrgMembers /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/settings" element={<ProtectedRoute><OrgSettings /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/fulfillment-settings" element={<ProtectedRoute><FulfillmentSettings /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs/upload" element={<ProtectedRoute><UploadDesign /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs/:designId/edit" element={<ProtectedRoute><EditDesign /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs/by-number/:designNumber/edit" element={<ProtectedRoute><DesignByNumberRedirect /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs/bulk-data" element={<ProtectedRoute><OrgDesignBulkEditData /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs/bulk-designs" element={<ProtectedRoute><OrgDesignBulkEditDesigns /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs/bulk-mockups" element={<ProtectedRoute><OrgDesignBulkEditMockups /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs/bulk-categories" element={<ProtectedRoute><OrgDesignBulkEditCategories /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs/bulk-keywords" element={<ProtectedRoute><OrgDesignBulkEditKeywords /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs/bulk-thumbs" element={<ProtectedRoute><OrgDesignBulkEditThumbs /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs/bulk-ai-data" element={<ProtectedRoute><OrgBulkAIData /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/socials" element={<ProtectedRoute><OrgSocials /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/designs/bulk-upload" element={<ProtectedRoute><UploadDesignsBulk /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/dtf-orders" element={<ProtectedRoute><OrgDTFOrders /></ProtectedRoute>} />
                    <Route path="/org/:orgSlug/dtf/upload-gangsheet" element={<ProtectedRoute><UploadGangsheet /></ProtectedRoute>} />
                    <Route path="/admin/dashboard" element={<ProtectedRoute requireRole={['admin', 'superadmin']}><AdminDashboard /></ProtectedRoute>} />
                    <Route path="/admin/addons" element={<ProtectedRoute requireRole={['admin', 'superadmin']}><AdminAddons /></ProtectedRoute>} />
                    <Route path="/admin/addon-settings" element={<ProtectedRoute requireRole={['admin', 'superadmin']}><AddonSettings /></ProtectedRoute>} />
                    <Route path="/admin/system-fulfillment" element={<ProtectedRoute requireRole={['superadmin']}><SystemFulfillment /></ProtectedRoute>} />
                    <Route path="/admin/apparel" element={<ProtectedRoute requireRole="superadmin"><AdminApparel /></ProtectedRoute>} />
                    <Route path="/admin/combos" element={<ProtectedRoute requireRole="superadmin"><AdminCombos /></ProtectedRoute>} />
                    <Route path="/admin/messages" element={<ProtectedRoute requireRole="superadmin"><AdminMessages /></ProtectedRoute>} />
                    <Route path="/admin/messaging" element={<ProtectedRoute requireRole="superadmin"><AdminMessaging /></ProtectedRoute>} />
                    <Route path="/admin/design-categories" element={<ProtectedRoute requireRole="superadmin"><AdminDesignCategories /></ProtectedRoute>} />
                    <Route path="/admin/clothing-categories" element={<ProtectedRoute requireRole="superadmin"><AdminClothingCategories /></ProtectedRoute>} />
                    <Route path="/admin/page-data" element={<ProtectedRoute requireRole="superadmin"><AdminPageData /></ProtectedRoute>} />
                    <Route path="/admin/site-settings" element={<ProtectedRoute requireRole="superadmin"><SiteSettings /></ProtectedRoute>} />
                    <Route path="/admin/badwords" element={<ProtectedRoute requireRole={['admin', 'superadmin']}><BadwordsAdmin /></ProtectedRoute>} />
                    <Route path="/admin/coupons" element={<ProtectedRoute requireRole={['admin', 'superadmin']}><Coupons /></ProtectedRoute>} />
                    <Route path="/admin/openai-prompts" element={<ProtectedRoute requireRole="superadmin"><OpenAIPrompts /></ProtectedRoute>} />
                                  <Route path="/admin/featured" element={<ProtectedRoute requireRole="superadmin"><Featured /></ProtectedRoute>} />
              <Route path="/admin/shipping-prices" element={<ProtectedRoute requireRole="superadmin"><ShippingPrices /></ProtectedRoute>} />
              <Route path="/admin/clothing-size-maps" element={<ProtectedRoute requireRole={["admin","superadmin"]}><ClothingSizeMaps /></ProtectedRoute>} />
              <Route path="/admin/data-tx" element={<ProtectedRoute requireRole="superadmin"><DataTX /></ProtectedRoute>} />
                    <Route path="/organizations/:username" element={<PublicOrganization />} />
                    
                    {/* Design Details - SEO-friendly URLs with backward compatibility */}
                    <Route path="/designs/:orgSlug/:designSlug" element={<DesignDetails />} />
                    <Route path="/designDetails/:id" element={<DesignDetails />} />
                    
                    {/* Apparel Details - SEO-friendly URLs with backward compatibility */}
                    <Route path="/apparel/:brandSlug/:styleSlug" element={<ApparelDetails />} />
                    <Route path="/apparel/:id" element={<ApparelDetails />} />
                    
                    {/* Combo Details - SEO-friendly URLs with backward compatibility */}
                    <Route path="/combos/:orgSlug/:comboSlug" element={<ComboDetails />} />
                    <Route path="/combos/:id" element={<ComboDetails />} />
                    
                                  {/* License Details - Public curated license pages */}
              <Route path="/license/:licenseSlug" element={<LicenseDetails />} />
                    
                    <Route path="/collections/:collectionId" element={<UserCollections />} />
                    <Route path="/favorites/:userId" element={<UserFavorites />} />
                    <Route path="/checkout/success" element={<CheckoutSuccess />} />
                    <Route path="/checkout/cancel" element={<CheckoutCancel />} />
                    {/* Dynamic catch-all route for public pages */}
                    <Route path="*" element={<PublicDynamicPage />} />
                  </Routes>
                </Layout>
              } />
            </Routes>
          </BrowserRouter>
        </CartProvider>
      </ThemeProvider>
    </UserProvider>
  );
};

export default App;